<template>
  <div class="tree-table-container">
    <div class="common-table-container">
      <div class="bbsl-table-search">
        <el-page-header style="width: 20%;margin-right: 20px;" @back="goBack" :content="monitor.typeName">
        </el-page-header>
        <el-form v-model="queryParam" :inline="true">
          <el-form-item label="监控点名称：">
            <el-input clearable placeholder="请输入监控点名称" v-model="params.name"
                      style="width: 200px">
            </el-input>
          </el-form-item>
          <el-form-item label="重点设备">
            <el-select v-model="params.catalogCode" clearable placeholder="请选择重点设备">
              <el-option label="一般设备" value="0"></el-option>
              <el-option label="重点设备" value="1"></el-option>
            </el-select>
          </el-form-item>
          <el-form-item label="在线状态">
            <el-select v-model="params.status" clearable placeholder="请选择在线状态">
              <el-option v-for="item in sbztList" :label="item.name" :value="item.value">
              </el-option>
            </el-select>
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" @click="onClickSearch">搜索
            </el-button>
          </el-form-item>
          <el-form-item v-if="false">
            <div class="SynchronizationPoint">
              <el-button @click="onClickSynch">
                <div class="buttonClass">
                  <div class="icon">
                    <img src="@/assets/img/tongbuBlue.png" />
                  </div>
                  <span>同步点位</span>
                </div>
              </el-button>
            </div>
          </el-form-item>
        </el-form>
      </div>
      <div class="bbsl-table-content" ref="contentPanel">
        <div class="bbsl-btn-content" ref="btnPanel">
        </div>
        <el-table stripe size="mini" :height="tableMaxHeight" :style="{width: '100%'}" v-loading="loading"
                  ref="multipleSelection" border :data="tableData" :row-key="getRowKey"
                  @selection-change="handleSelectionChange" :header-cell-style="{'text-align': 'center'}"
                  :cell-style="{'text-align': 'center'}">
          <el-table-column type="index" width="55" align="center" label="序号" show-overflow-tooltip>
          </el-table-column>
          <el-table-column min-width="140" sortable prop="name" label="监控点名称" show-overflow-tooltip>
          </el-table-column>
          <el-table-column min-width="140" sortable prop="code" label="监控点编码" show-overflow-tooltip>
          </el-table-column>
          <el-table-column min-width="100" sortable prop="lgtd" label="经度" show-overflow-tooltip>
          </el-table-column>
          <el-table-column min-width="100" sortable prop="lttd" label="纬度" show-overflow-tooltip>
          </el-table-column>
          <el-table-column min-width="150" sortable prop="important" label="是否是重点设备" show-overflow-tooltip>
            <template slot-scope="scope">
              <span v-if="scope.row.important == '1'">重点设备</span>
              <span v-else-if="scope.row.important == '0'">一般设备</span>
            </template>
          </el-table-column>
          <el-table-column min-width="160" sortable prop="life" label="使用期限" show-overflow-tooltip>
          </el-table-column>
          <el-table-column min-width="100" sortable prop="status" label="在线状态" show-overflow-tooltip
                           width="150">
            <template slot-scope="scope">
							<span :style="{
                  color:
                    scope.row.status == 0
                      ? 'red'
                      : scope.row.status == 1
                      ? 'green'
                      : '',
                  width: '100%'
                }">
								{{
                  scope.row.status == 0
                    ? '异常'
                    : scope.row.status == 1
                    ? '正常'
                    : scope.row.status == 2
                    ? '故障'
                    : scope.row.status == -1
                    ? '报废'
                    : ''
                }}</span>
            </template>
          </el-table-column>
        </el-table>
        <el-pagination ref="paginationPanel" align="right" class="bbsl-pagination" background
                       @size-change="handleSizeChange" @current-change="handleCurrentChange"
                       :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                       :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                       :total="total"></el-pagination>
      </div>
    </div>
  </div>
</template>
<script>
import {
  mapState
} from 'vuex'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import equipmentManage from '@/api/device/equipmentManage.js'
import VideoFacilities from '@/api/device/VideoFacilities.js'

import req from '@/request.js'
import {
  TableMixin
} from '@/mixins/tableMixin'
import videoFormDialog from '@/views/Device/deviceManage/components/videoFormDialog'

export default {
  name: 'VideoFacilities',
  components: {
    videoFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      //携带参数
      uploadData: {
        catalogCode: ''
      },
      reviseDat: '',
      reviseVisible: false,
      reviseStart: '',
      catalogs: [], //视频目录
      loading: false,
      fullId: '', //目录树编码
      catalogCode: '', //目录编码
      catalogPlatform: '',
      multipleSelection: [], // 复选框
      params: {
        name: '',
        catalogCode: '',
        status: '',
        zoneCode: ''
      },
      querys: [{
        group: 'main',
        operation: 'LIKE',
        parentGroup: '',
        property: 'r.name_',
        relation: 'AND',
        value: ''
      },
        // {
        //   group: 'main',
        //   operation: 'RIGHT_LIKE',
        //   parentGroup: '',
        //   property: 'z.full_id_',
        //   relation: 'AND',
        //   value: ''
        // },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'r.catalog_code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'e.important_',
          relation: 'AND',
          value: ''
        }
      ],
      regionIndexCode: '',
      total: 0,
      tableData: [],
      videoTree: [],
      defaultProps: {
        value: 'code',
        label: 'name'
      },
      data: [],
      filterText: '',
      show: false,
      rules: {
        name: [{
          required: true,
          message: '请输入区域名称',
          trigger: 'change'
        }],
        code: [{
          required: true,
          message: '请输入区域编码',
          trigger: 'change'
        }]
      },
      titles: '',
      area: {
        code: '',
        name: ''
      },
      pArea: null,
      activeCollapseDia: '1',
      showTreeNode: false,
      url: {
        delete: '/biz/catalog/base/point/'
      },
      sbztList: [],
      monitor: {}
    }
  },

  watch: {
    filterText(val) {
      this.$refs.tree.filter(val)
    }
  },
  //获取token
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
    //在created里面区获取actionUrl
    this.monitor = JSON.parse(localStorage.getItem('monitor'))
    this.actionUrl = window.context.portal
    this.sbztList = dictUtils.getDictItemsFromCache('sbzt')

    // this.getTreeDict()
  },

  methods: {
    goBack() {
      this.$router.push({
        path: 'DeviceAnalysis'
      })
    },
    handleDbClick(val) {
      console.log(val)
      this.$refs.formModal.editBasic(val)
    },
    //上传成功
    handleAvatarSuccess(res, file) {
      //提示
      this.$notify({
        type: 'success',
        message: this.$t('domestic.success'),
        duration: 2000
      })
      this.loadData() //调用用页面查询接口，刷新数据
    },
    //上传失败
    handleAvatarError(err, file, fileList) {
      //提示
      this.$notify({
        type: 'error',
        message: this.$t('domestic.failure'),
        duration: 2000
      })
    },
    //数据导入
    importData() {
    },
    //数据导出
    exportData() {
      let exportParam = {
        ...this.queryParam
      }
      exportParam.pageBean = {
        page: 1,
        pageSize: -1
      }
      console.log(exportParam)
      equipmentManage.exportPointBase(exportParam, res => {
      })
      //   this.loadData()
    },
    //
    handleClose() {
      this.reviseVisible = false
    },
    //
    revise(val) {
      this.reviseVisible = true
      this.reviseDat = val
    },
    reviseBtn() {
      // console.log(this.reviseDat)
      equipmentManage.updateStatus({
          id: this.reviseDat.id,
          productCode: 'video',
          status: this.reviseStart
        },
        res => {
          this.loadData()
          this.reviseVisible = false
          //   if (res.state) {
          //     this.$message({
          //       message: res.message,
          //       type: 'success'
          //     })
          //     this.loadData()
          //     this.reviseVisible = false
          //   }
        }
      )
    },
    equipment(val) {
      console.log(val)
      let importantData = 0
      if (val.important == 1 && val.important) {
        importantData = 0
      } else {
        importantData = 1
      }
      equipmentManage.updateImportantPoint({
          id: val.id,
          important: importantData
        },
        res => {
          // console.log(res)
          if (res.state) {
            this.$message({
              message: res.message,
              type: 'success'
            })
            this.loadData()
            // this.reviseVisible = false
          }
        }
      )
    },
    handleDeleteSite(row) {
      VideoFacilities.deleteVideoSite(row.id, res => {
        if (res.state) {
          this.$message.success('删除成功')
          this.loadData()
        }
      })
    },
    selectable(row) {
      if (row.dataType == 2) {
        return true
      } else {
        return false
      }
    },
    handleAdd() {
      if (!this.regionIndexCode) {
        this.$message.warning('请选择新增视频点位所属区域！')
        return
      } else {
        let pData = {
          catalogCode: this.catalogCode,
          platform: this.catalogPlatform,
          zoneCode: this.regionIndexCode
        }
        this.$refs.formModal.add(pData)
      }
    },
    reload() {
    },
    handleCloseDia() {
      this.showTreeNode = false
      this.area = {
        code: '',
        name: ''
      }
      this.pArea = null
    },
    handleSaveDia() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let API = VideoFacilities.updateVideoArea
          if (this.titles == '新增') {
            this.area.baseCode = this.pArea.baseCode
            this.area.parentId = this.pArea.id
            this.area.platform = this.pArea.platform
            API = VideoFacilities.addVideoArea
          }
          console.log(this.area)
          API(this.area, res => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.titles + '视频区域成功！',
                duration: 2000
              })
              this.getTree()
              this.handleCloseDia()
            } else {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80
              })
            }
          })
        }
      })
    },
    append(data, type) {
      console.log(data, type, 'data, type')
      this.activeCollapseDia = '1'
      this.titles = '新增'
      this.showTreeNode = true
      this.pArea = data
    },
    upDateinfo(data, type) {
      this.titles = '修改'
      this.area = data
      this.showTreeNode = true
    },
    // 删除视频目录
    remove(data) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning'
      })
        .then(() => {
          VideoFacilities.deleteVideoArea(data.id, res => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: '删除成功',
                duration: 2000
              })
              this.getTree()
            } else {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80
              })
            }
          })
        })
        .catch(() => {
        })
    },

    // 获取目录
    getTreeDict() {
      VideoFacilities.getVideoF({}, res => {
        this.catalogs = res.value
        this.catalogCode = this.catalogs[0].code
        this.catalogPlatform = this.catalogs[0].platform
        this.getTree()
      })
    },
    // 获取目录树
    getTree() {
      let query = {
        zoneCode: this.catalogCode
      }
      VideoFacilities.getVideoTree(query, res => {
        this.videoTree = res.value
        this.fullId = this.videoTree.length ? this.videoTree[0].fullId : ''
        if (this.videoTree.length) {
          this.loadData()
        } else {
          this.videoTree[0] = {
            name: '--',
            id: '-1',
            dataType: 1,
            baseCode: this.catalogCode,
            platform: this.catalogPlatform
          }
        }
      })
    },
    // 切换目录
    changeCatalog(val) {
      this.$refs.multipleSelection.clearSelection() //切换，选中就归零
      if (val) {
        this.catalogCode = val
        this.catalogPlatform = val
        let platform = this.catalogs.filter(item => item.code == val)[0]
          .platform
        this.catalogPlatform = platform
        this.getTree()
      } else {
        this.catalogCode = ''
        this.catalogPlatform = ''
        this.videoTree = []
        this.$set(this.videoTree, this.videoTree, res.value)
      }
    },
    handleUpdate(val) {
      VideoFacilities.getDetails(val.code, res => {
        if (res) {
          let path = this.$route.path
          if (path.indexOf('frontPlat') !== -1) {
            this.$router.push({
              name: 'VideoDetails',
              query: res
            })
          } else {
            this.$router.push({
              name: 'VideoDetailsLink',
              query: res
            })
          }
        }
      })
    },
    changeNode(data) {
      console.log(data)
      if (data) {
        this.regionIndexCode = data.code
        this.fullId = data.fullId
        this.params.zoneCode = data.code
        //如果点击树，选中状态归0
        this.$refs.multipleSelection.clearSelection()
        this.loadData()
      }
    },
    loadData() {
      this.loading = false
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.params = this.params
      this.uploadData.catalogCode = this.catalogCode

      VideoFacilities.getList(this.queryParam, res => {
        if (res) {
          this.tableData = res.rows
          this.total = res.total
          this.loading = false

        }
      })
    },
    //同步数据
    synchroTree() {
      VideoFacilities.asycCataLog(res => {
        if (res.state) {
          if (res.state) {
            this.$message.success('目录同步成功')
            this.getTreeDict()
          } else {
            this.$message.error('同步失败')
          }
        }
      })
    },
    synchro(node, data) {
      VideoFacilities.asycCataLogZone({
        treeCode: this.catalogCode
      }, res => {
        if (res.state) {
          this.$message.success('区域同步成功')
          this.getTreen()
        } else {
          this.$message.error('同步失败')
        }
      })
    },
    onClickSynch() {
      VideoFacilities.getSynch({}, res => {
        if (res.state) {
          this.$message.success('同步成功')
        } else {
          this.$message.error('同步失败')
        }
      })
    },
    filterNode(value, data) {
      if (!value) return true
      return data.name.indexOf(value) !== -1
    },
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.loadData()
    },
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.loadData()
    },
    // handleSelectionChange(val) {
    //     this.multipleSelection = val.map((item) => {
    //         return item.id
    //     })
    // },
    // // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    // // 点击查询
    onClickSearch() {
      this.queryParam.pageBean.page = 1
      this.loadData()
    }
  }
}
</script>
<style lang="scss" scoped>
a {
  color: #fff;
}

::v-deep .el-card__body {
  padding: 0% !important;
}

//  ::v-deep .el-table {
//   height: 92% !important;
// }
.bbsl-common-page {
  display: flex;
  justify-content: space-between;
}

// .bbsl-table-content {
//   height: calc(93% - 70px);
// }
.bbsl-btn-content {
  display: flex;
}

.el-tree-node__content {
  width: 100% !important;
  height: 40px !important;
  flex: 1;
  display: flex !important;
  // align-items: center !important;
  justify-content: space-around !important;
  font-size: 14px;
  // padding-right: 8px;
}

.btn-content {
  display: flex;
}

.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}

.el-select-dropdown__item {
  color: #9a9a9a !important;
}

.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}

.btn-content :first-child {
  margin: 0 0 0 0 !important;
}

.el-card__body {
  width: 100% !important;
  height: 100% !important;
}

.custom-tree-node {
  flex: 1;
  display: flex;
  align-items: center;
  justify-content: space-between;
  font-size: 14px;
  padding-right: 5px;
}

// .custom-tree-node {
//   box-sizing: border-box;
//   display: flex;
//   justify-content: space-around !important;
// }

.el-card {
  width: 100% !important;
  height: 100% !important;
}

.el-main {
  width: 100% !important;
  height: 100% !important;
}

.fullheight {
  display: flex !important;
  width: 100% !important;
  height: 100%;
}

.content-left {
  width: 20% !important;
  //   border-right: 1px solid #ccc;
}

.content-right {
  width: 80% !important;
}

.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}

.el-radio-group {
  vertical-align: sub;
}

::-webkit-scrollbar {
  background: #fff !important;
}

::v-deep .custom-tree-node {
  span {
    font-size: 14PX !important;
  }
}

.el-popover {
  min-width: 35px !important;
  padding: 5px 0 !important;
}

.line {
  display: block !important;
  height: 1px !important;
  background: #ccc !important;
}

.bbsl-pagination {
  bottom: 10px !important;
}

.synchronizationML {
  width: 80px;
  height: 32px;
  margin-left: 10px;

  .el-button {
    width: 100%;
    height: 100%;
    padding: 0px;

    .buttonClass {
      width: 100%;
      height: 27px;
      display: flex;
      align-items: center;
      justify-content: center;

      .icon {
        width: 16px;
        margin: 0px 1px;

        img {
          width: 100%;
          height: auto;
        }
      }

      span {
        margin: 0px 1px;
      }
    }
  }
}

.SynchronizationPoint {
  display: inline-block;
  width: 100px;
  height: 34px;

  .el-button {
    width: 100%;
    height: 100%;
    padding: 0px;
    margin: 0px;
    border: 1px solid #41a1fe;
    margin-top: -1px;

    .buttonClass {
      width: 100%;
      height: 100%;
      display: flex;
      align-items: center;
      justify-content: center;

      .icon {
        width: 25px;
        margin: 0px 2px;

        img {
          width: 100%;
          height: auto;
        }
      }

      span {
        margin: 0px 2px;
        color: #41a1fe;
      }
    }
  }
}

.bbsl-table-search {
  ::v-deep .el-form {
    display: flex;
    align-items: center;

    .el-form-item {
      &:last-child {
        .el-form-item__content {
          display: flex !important;
          align-items: center;
        }
      }
    }
  }
}

.common-tree-container {
  width: 100% !important;
  overflow-y: auto;
}

::v-deep .el-tree-node > .el-tree-node__children {
  overflow: visible;
}
</style>
